@@ -1,6 +1,6 @@
 def print_lol (the_list):
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item)
+            print_lol(each_item,level+1)
         else:
             print(each_item)
\ No newline at end of file
